@@ -20,11 +20,13 @@ class PluginManager
 		PluginManager ();
 		~PluginManager ();
 
+		typedef std::list<Plugin*> PluginList;
+
 		/* List of loaded plugins */
-		std::list<Plugin*> getPlugins();
+		PluginList getPlugins();
 
 		/* List of enabled plugins */
-		std::list<Plugin*> getEnabledPlugins();
+		PluginList getEnabledPlugins();
 
 		/* Load all plugins in the directory */
 		void scan (std::string const &pluginDir);
@@ -32,6 +34,10 @@ class PluginManager
 		/* Look for data files in plugin paths */
 		Glib::ustring findDataFile (Glib::ustring file);
 
+		/* Callback for progression while in plugins */
+		void *progressObject_;
+		bool (*progressCallback_)(void*);
+
 	private:
 		/* Python module search locations */
 		std::vector<Glib::ustring> pythonPaths_;
