@@ -13,12 +13,20 @@
 #ifndef TRANSFER_H
 #define TRANSFER_H
 
+#include <gtkmm/progressbar.h>
 #include <glibmm/ustring.h>
 #include <glibmm/exception.h>
 
+class Progress;
+
 namespace Transfer {
 
-Glib::ustring &getRemoteFile (
+void downloadRemoteFile (
+	Glib::ustring const &source,
+	Glib::ustring const &dest,
+	Progress &progress);
+
+Glib::ustring &readRemoteFile (
 	Glib::ustring const &title,
 	Glib::ustring const &messagetext,
 	Glib::ustring const &filename);
